"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validatePackageName = exports.validatePluginSanityJson = exports.validateStudioConfig = exports.validateBabelConfig = exports.validateDeprecatedDependencies = exports.validateSanityDependencies = exports.validatePkgUtilsDependency = exports.validateTsConfig = exports.validateScripts = exports.validateModule = exports.validateNodeEngine = exports.expectedScripts = void 0;
const outdent_1 = __importDefault(require("outdent"));
// @ts-expect-error missing types
const validate_npm_package_name_1 = __importDefault(require("validate-npm-package-name"));
// @ts-expect-error missing types
const find_babel_config_1 = __importDefault(require("find-babel-config"));
const constants_1 = require("../../constants");
const banned_packages_1 = require("../../configs/banned-packages");
const path_1 = __importDefault(require("path"));
const files_1 = require("../../util/files");
const chalk_1 = __importDefault(require("chalk"));
exports.expectedScripts = {
    prebuild: `plugin-kit verify-package --silent && pkg-utils`,
    build: 'pkg-utils build',
    watch: 'pkg-utils watch',
    'link-watch': 'plugin-kit link-watch',
    prepublishOnly: 'npm run build',
};
const expectedModulesFields = ['source', 'exports', 'main', 'module', 'files'];
const expectedCompilerOptions = {
    jsx: 'preserve',
    moduleResolution: 'node',
    target: 'esnext',
    module: 'esnext',
    sourceMap: false,
    inlineSourceMap: false,
    esModuleInterop: true,
    skipLibCheck: true,
    isolatedModules: true,
    downlevelIteration: true,
    declaration: true,
    allowSyntheticDefaultImports: true,
    rootDir: 'src',
};
function validateNodeEngine(packageJson) {
    var _a, _b;
    const nodeVersionRange = '>=14.0.0';
    if (((_a = packageJson.engines) === null || _a === void 0 ? void 0 : _a.node) !== nodeVersionRange) {
        return [
            (0, outdent_1.default) `
        Expected package.json to contain engines.node: ">=14.0.0" to ensure Studio compatible builds,
        but it was: ${(_b = packageJson.engines) === null || _b === void 0 ? void 0 : _b.node}

        Please add the following to package.json:

        "engines": {
          "node": "${nodeVersionRange}"
        }`.trimStart(),
        ];
    }
}
exports.validateNodeEngine = validateNodeEngine;
function validateModule(packageJson) {
    const errors = [];
    const missingFields = expectedModulesFields.filter((field) => !packageJson[field]);
    if (missingFields.length) {
        errors.push((0, outdent_1.default) `
        Expected source, exports, main, module and files entries in package.json, but ${missingFields.join(', ')} where missing.

        Example:

        Given a plugin with entry-point in src/index.ts, using default @sanity/pkg-utils build command,
        package.json should contain the following entries to ensure that commonjs and esm outputs are built into lib:

        "source": "./src/index.ts",
        "exports": {
          ".": {
            "types": "./lib/src/index.d.ts",
            "source": "./src/index.ts",
            "import": "./lib/index.esm.js",
            "require": "./lib/index.js",
            "default": "./lib/index.js"
          }
        },
        "main": "./lib/index.js",
        "module": "./lib/index.esm.js",
        "types": "./lib/src/index.d.ts",
        "files": [
          "src",
          "lib"
        ],

        Refer to @sanity/pkg-utils for more: https://github.com/sanity-io/pkg-utils#sanitypkg-utils
  `.trimStart());
    }
    if (packageJson.typings) {
        errors.push((0, outdent_1.default) `Found typings field in package.json. Use types instead.`);
    }
    return errors;
}
exports.validateModule = validateModule;
function validateScripts(packageJson) {
    const errors = [];
    const divergentScripts = Object.entries(exports.expectedScripts).filter(([key, expectedCommand]) => {
        var _a;
        const command = (_a = packageJson.scripts) === null || _a === void 0 ? void 0 : _a[key];
        // check for includes instead of equals to give some leniency in command params and such
        return !command || !command.includes(expectedCommand);
    });
    if (divergentScripts.length) {
        errors.push((0, outdent_1.default) `
      The following script commands did not contain expected defaults: ${divergentScripts
            .map(([key]) => key)
            .join(', ')}

      This checks for that the commands-strings includes these terms.
      For example, this will validate ok:
      "prebuild": "npm run clean && ${exports.expectedScripts.prebuild}",

      Please add the following to your package.json "scripts":

      ${divergentScripts.map(([key, value]) => `"${key}": "${value}"`).join(',\n')}
  `.trimStart());
    }
    return errors;
}
exports.validateScripts = validateScripts;
function validateTsConfig(tsConfig) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const errors = [];
        const options = (_a = tsConfig.compilerOptions) !== null && _a !== void 0 ? _a : {};
        const wrongEntries = Object.entries(expectedCompilerOptions).filter(([key, value]) => {
            const option = options[key];
            return typeof value === 'string' && typeof option === 'string'
                ? value.toLowerCase() !== (option === null || option === void 0 ? void 0 : option.toLowerCase())
                : value !== option;
        });
        if (wrongEntries.length) {
            const expectedOutput = wrongEntries
                .map(([key, value]) => `"${key}": ${typeof value === 'string' ? `"${value}"` : value},`)
                .join('\n');
            errors.push((0, outdent_1.default) `
        Recommended tsconfig.json compilerOptions missing:

        The following fields had unexpected values: [${wrongEntries.map(([key]) => key).join(', ')}]
        Expected to find these values:
        ${expectedOutput}

        Please update your tsconfig.json accordingly.
      `.trimStart());
        }
        return errors;
    });
}
exports.validateTsConfig = validateTsConfig;
function validatePkgUtilsDependency({ devDependencies }) {
    if (!(devDependencies === null || devDependencies === void 0 ? void 0 : devDependencies['@sanity/pkg-utils'])) {
        return [
            (0, outdent_1.default) `
        package.json does not list @sanity/pkg-utils as a devDependency.
        @sanity/pkg-utils replaced parcel as the recommended build tool in @sanity/plugin-kit 2.0.0

        Please add it by running 'npm install --save-dev @sanity/pkg-utils'.
    `.trimStart(),
        ];
    }
    return [];
}
exports.validatePkgUtilsDependency = validatePkgUtilsDependency;
function validateSanityDependencies(packageJson) {
    const { dependencies, devDependencies, peerDependencies } = packageJson;
    const allDependencies = Object.assign(Object.assign(Object.assign({}, dependencies), devDependencies), peerDependencies);
    const illegalDeps = Object.keys(allDependencies).filter((dep) => banned_packages_1.mergedPackages.includes(dep));
    const deps = new Set(illegalDeps);
    const unique = [...deps.values()];
    if (unique.length) {
        return [
            (0, outdent_1.default) `
        package.json depends on "@sanity/*" packages that have moved into "sanity" package.

        The following dependencies should be replaced with "sanity":
        - ${unique.join('\n- ')}

        Refer to the reference docs to find replacement imports:
        ${constants_1.urls.refDocs}
    `.trimStart(),
        ];
    }
    return [];
}
exports.validateSanityDependencies = validateSanityDependencies;
function validateDeprecatedDependencies(packageJson) {
    const { dependencies, devDependencies, peerDependencies } = packageJson;
    const allDependencies = Object.assign(Object.assign(Object.assign({}, dependencies), devDependencies), peerDependencies);
    const illegalDeps = Object.keys(allDependencies).filter((dep) => banned_packages_1.deprecatedDevDeps.includes(dep));
    const deps = new Set(illegalDeps);
    const unique = [...deps.values()];
    if (unique.length) {
        return [
            (0, outdent_1.default) `
        package.json contains deprecated dependencies that should be removed:
        - ${unique.join('\n- ')}
    `.trimStart(),
        ];
    }
    return [];
}
exports.validateDeprecatedDependencies = validateDeprecatedDependencies;
function validateBabelConfig({ basePath }) {
    return __awaiter(this, void 0, void 0, function* () {
        const babelConfig = yield (0, find_babel_config_1.default)(basePath);
        if (babelConfig.file) {
            return [
                (0, outdent_1.default) `
        Found babel-config file: ${babelConfig.file}. When using default @sanity/plugin-kit build command,
        this is probably not needed.

        Delete the ${babelConfig.file} file, or disable this check.
      `.trimStart(),
            ];
        }
        return [];
    });
}
exports.validateBabelConfig = validateBabelConfig;
function validateStudioConfig({ basePath }) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j;
    return __awaiter(this, void 0, void 0, function* () {
        const suffixes = ['ts', 'js', 'tsx', 'jsx'];
        const withSuffix = (fileBases) => fileBases.flatMap((file) => suffixes.map((suffix) => `${file}.${suffix}`));
        const filenames = withSuffix(['sanity.config', 'sanity.cli']);
        const files = {};
        for (const filename of filenames) {
            const filepath = path_1.default.normalize(path_1.default.join(basePath, filename));
            files[filename] = yield (0, files_1.fileExists)(filepath);
        }
        const sanityJson = yield (0, files_1.readJson5File)({ basePath, filename: 'sanity.json' });
        const hasConfigFile = (fileBase) => withSuffix([fileBase]).some((filename) => files[filename]);
        const hasCliConfig = hasConfigFile('sanity.cli');
        const hasStudioConfig = hasConfigFile('sanity.config');
        const errors = [];
        if (sanityJson) {
            const info = [
                (0, outdent_1.default) `
        Found sanity.json. This file is not used by Sanity Studio V3.

        Please consult the Studio V3 migration guide:
         ${constants_1.urls.migrationGuideStudio}
        It will detail how to convert sanity.json to sanity.config.ts (or .js) and sanity.cli.ts (or .js) equivalents.
      `.trimStart(),
                ((_a = sanityJson.plugins) === null || _a === void 0 ? void 0 : _a.length) &&
                    (0, outdent_1.default) `
        For V3 versions and alternatives to V2 plugins, please refer to the Sanity Exchange:
        ${constants_1.urls.sanityExchange}
      `.trimStart(),
            ].filter((s) => !!s);
            errors.push(info.join('\n\n'));
        }
        if (!hasCliConfig) {
            errors.push((0, outdent_1.default) `
        sanity.cli.(${suffixes.join(' | ')}) missing. Please create a file named sanity.cli.ts with the following content:

        ${chalk_1.default.green((0, outdent_1.default) `
        import {createCliConfig} from 'sanity/cli'

        export default createCliConfig({
          api: {
            projectId: '${(_c = (_b = sanityJson === null || sanityJson === void 0 ? void 0 : sanityJson.api) === null || _b === void 0 ? void 0 : _b.projectId) !== null && _c !== void 0 ? _c : 'project-id'}',
            dataset: '${(_e = (_d = sanityJson === null || sanityJson === void 0 ? void 0 : sanityJson.api) === null || _d === void 0 ? void 0 : _d.dataset) !== null && _e !== void 0 ? _e : 'dataset'}',
          }
        })`)}

        Make sure to replace the projectId and dataset fields with your own.

        For more, see ${constants_1.urls.migrationGuideStudio}
    `.trimStart());
        }
        if (!hasStudioConfig) {
            errors.push((0, outdent_1.default) `
        sanity.config.(${suffixes.join(' | ')}) missing. At a minimum sanity.config.ts should contain:

        ${chalk_1.default
                .green((0, outdent_1.default) `
            import { createConfig } from "sanity"
            import { deskTool } from "sanity/desk"

            export default createConfig({
              name: "default",

              projectId: '${(_g = (_f = sanityJson === null || sanityJson === void 0 ? void 0 : sanityJson.api) === null || _f === void 0 ? void 0 : _f.projectId) !== null && _g !== void 0 ? _g : 'project-id'}',
              dataset: '${(_j = (_h = sanityJson === null || sanityJson === void 0 ? void 0 : sanityJson.api) === null || _h === void 0 ? void 0 : _h.dataset) !== null && _j !== void 0 ? _j : 'dataset'}',

              plugins: [
                deskTool(),
              ],

              schema: {
                types: [
                  /* put your v2 schema-types here */
                ],
              },
            })`)
                .trimStart()}

        Make sure to replace the projectId and dataset fields with your own.

        For more, see ${constants_1.urls.migrationGuideStudio}
    `.trimStart());
        }
        return errors.length ? [errors.join(`\n\n---\n\n`)] : [];
    });
}
exports.validateStudioConfig = validateStudioConfig;
function validatePluginSanityJson({ basePath, packageJson, }) {
    var _a, _b;
    return __awaiter(this, void 0, void 0, function* () {
        const sanityJson = yield (0, files_1.readJson5File)({ basePath, filename: 'sanity.json' });
        const expectedDefaults = {
            parts: [
                {
                    implements: 'part:@sanity/base/sanity-root',
                    path: './v2-incompatible.js',
                },
            ],
        };
        const hasSinglePart = sanityJson &&
            Object.keys(sanityJson).length === 1 &&
            (sanityJson === null || sanityJson === void 0 ? void 0 : sanityJson.parts) &&
            sanityJson.parts.length === 1;
        const firstPart = hasSinglePart ? (_a = sanityJson === null || sanityJson === void 0 ? void 0 : sanityJson.parts) === null || _a === void 0 ? void 0 : _a[0] : undefined;
        const correctImplements = (firstPart === null || firstPart === void 0 ? void 0 : firstPart.implements) === expectedDefaults.parts[0].implements;
        const pathExists = (firstPart === null || firstPart === void 0 ? void 0 : firstPart.path) && (yield (0, files_1.fileExists)(path_1.default.normalize(path_1.default.join(basePath, firstPart.path))));
        const hasDependency = !!((_b = packageJson.dependencies) === null || _b === void 0 ? void 0 : _b[constants_1.incompatiblePluginPackage]);
        const isValid = sanityJson && hasSinglePart && correctImplements && pathExists && hasDependency;
        if (!isValid) {
            const errors = [
                !sanityJson ? 'sanity.json does not exist' : null,
                !hasSinglePart ? 'sanity.json should have exactly one entry in "parts", but did not.' : null,
                !correctImplements
                    ? `The part should implement ${expectedDefaults.parts[0].implements}, but did not.`
                    : null,
                (firstPart === null || firstPart === void 0 ? void 0 : firstPart.path) && !pathExists
                    ? `The file in "path", ${firstPart === null || firstPart === void 0 ? void 0 : firstPart.path}, does not exist.`
                    : null,
                !hasDependency
                    ? (0, outdent_1.default) `
      package.json should have ${constants_1.incompatiblePluginPackage} as a dependency, but did not.
        Install it with: npm install --save ${constants_1.incompatiblePluginPackage}
      `.trimStart()
                    : null,
            ].filter((e) => !!e);
            return [
                (0, outdent_1.default) `
        Invalid sanity.json. It is used for compatibility checking in V2 studios:

        - ${errors.join('\n- ')}

        sanity.json will only be used when incorrectly installing a v3 plugin in a v2 Studio.

        This check ensures that sanity.json conforms with the usage section of
        ${constants_1.urls.incompatiblePlugin}
    `.trimStart(),
            ];
        }
        return [];
    });
}
exports.validatePluginSanityJson = validatePluginSanityJson;
function validatePackageName(packageJson) {
    var _a, _b;
    const valid = (0, validate_npm_package_name_1.default)(packageJson.name);
    if (!valid.validForNewPackages) {
        return [`Invalid package.json: "name" is invalid: ${valid.errors.join(', ')}`];
    }
    const isScoped = (_a = packageJson.name) === null || _a === void 0 ? void 0 : _a.startsWith('@');
    if (!isScoped && !((_b = packageJson.name) === null || _b === void 0 ? void 0 : _b.startsWith('sanity-plugin-'))) {
        return [
            `Invalid package.json: "name" should be prefixed with "sanity-plugin-" (or scoped - @your-company/plugin-name)`,
        ];
    }
}
exports.validatePackageName = validatePackageName;
//# sourceMappingURL=validations.js.map