"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runTscMaybe = exports.createValidator = exports.disableCheckText = exports.verifyFlags = exports.verifyPackageConfigDefaults = exports.readFile = void 0;
const log_1 = __importDefault(require("../../util/log"));
const fs_1 = __importDefault(require("fs"));
const sharedFlags_1 = __importDefault(require("../../sharedFlags"));
const chalk_1 = __importDefault(require("chalk"));
const outdent_1 = __importDefault(require("outdent"));
const command_parser_1 = require("../../util/command-parser");
exports.readFile = fs_1.default.promises.readFile;
const splitLine = `\n----------------------------------------------------------`;
exports.verifyPackageConfigDefaults = {
    packageName: true,
    module: true,
    tsconfig: true,
    tsc: true,
    dependencies: true,
    babelConfig: true,
    sanityV2Json: true,
    eslintImports: true,
    scripts: true,
    'pkg-utils': true,
    nodeEngine: true,
    studioConfig: true,
};
exports.verifyFlags = Object.assign(Object.assign({}, sharedFlags_1.default), { single: {
        default: false,
        type: 'boolean',
    } });
function disableCheckText(checkKey) {
    return chalk_1.default.grey((0, outdent_1.default) `
              To skip this validation add the following to your package.json:
              "sanityPlugin": {
                 "verifyPackage": {
                    "${checkKey}": false
                 }
              }
          `.trimStart());
}
exports.disableCheckText = disableCheckText;
function createValidator(verifyConfig, flags, errors) {
    return function validation(checkKey, task) {
        return __awaiter(this, void 0, void 0, function* () {
            if (verifyConfig[checkKey] !== false) {
                const result = yield task();
                if (result === null || result === void 0 ? void 0 : result.length) {
                    result.push(disableCheckText(checkKey));
                    const errorMessage = result.join('\n\n');
                    errors.push(errorMessage);
                    log_1.default.error(`\n` + errorMessage + splitLine);
                }
            }
            if (flags.single && errors.length) {
                throw new Error((0, outdent_1.default) `Detected outstanding upgrade issues.

        Fail-fast (--single) mode enabled, stopping validation here.
        `);
            }
        });
    };
}
exports.createValidator = createValidator;
function runTscMaybe(verifyConfig, tsConfig) {
    return __awaiter(this, void 0, void 0, function* () {
        if (tsConfig && verifyConfig.tsc !== false) {
            log_1.default.info('All checks ok, running Typescript compiler.');
            const { code } = yield (0, command_parser_1.runCommand)('tsc --noEmit');
            if (code !== 0) {
                throw new Error('Compilation failed. See output above.\n\n' + disableCheckText('tsc'));
            }
        }
    });
}
exports.runTscMaybe = runTscMaybe;
//# sourceMappingURL=verify-common.js.map