#!/usr/bin/env node
'use strict';
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.cliEntry = void 0;
const meow_1 = __importDefault(require("meow"));
const log_1 = __importDefault(require("./util/log"));
const cmds_1 = __importDefault(require("./cmds"));
const sharedFlags_1 = __importDefault(require("./sharedFlags"));
const constants_1 = require("./constants");
function cliEntry(argv = process.argv, autoExit = true) {
    return __awaiter(this, void 0, void 0, function* () {
        const cli = (0, meow_1.default)(`
	Usage
	  $ ${constants_1.cliName} [--help] [--debug] <command> [<args>]

  These are common commands used in various situations:

    init            Create a new Sanity plugin
    inject          Inject config into an existing Sanity v3 plugin
    verify-package  Check that a Sanity plugin package follows V3 conventions. Prints upgrade steps.
    verify-studio   Check that a Sanity Studio follows V3 conventions. Prints upgrade steps.
    link-watch      Recompiles plugin automatically on changes and runs yalc push --publish
    version         Show the version of ${constants_1.cliName} currently installed

  Options
    --silent        Do not print info and warning messages
    --verbose       Log everything. This option conflicts with --silent
    --debug         Print stack trace on errors
    --version       Output the version number
    --help          Output usage information

  Examples
    # Init a new plugin in current directory
    $ ${constants_1.cliName} init

    # Init a new plugin in my-sanity-plugin directory
    $ ${constants_1.cliName} init my-sanity-plugin

    # Check that a Sanity plugin package in current directory follows V3 conventions
    $ ${constants_1.cliName} verify-package

    # Check that a Sanity Studio in current directory  follows V3 conventions
    $ ${constants_1.cliName} verify-studio
`, {
            autoHelp: false,
            flags: sharedFlags_1.default,
            argv: argv.slice(2),
        });
        const commandName = cli.input[0];
        if (!commandName) {
            cli.showHelp(); // Exits
        }
        if (!(commandName in cmds_1.default)) {
            console.error(`Unknown command "${commandName}"`);
            cli.showHelp(); // Exits
        }
        if (cli.flags.silent && cli.flags.verbose) {
            log_1.default.error(`--silent and --verbose are mutually exclusive`);
            cli.showHelp(); // Exits
        }
        // Lazy-load command
        const cmd = require(cmds_1.default[commandName]).default;
        try {
            log_1.default.setVerbosity(cli.flags);
            yield cmd({ argv: argv.slice(3) });
        }
        catch (err) {
            log_1.default.error(err instanceof TypeError || cli.flags.debug ? err.stack : err.message);
            // eslint-disable-next-line no-process-exit
            process.exit(1);
        }
    });
}
exports.cliEntry = cliEntry;
//# sourceMappingURL=cli.js.map