"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const meow_1 = __importDefault(require("meow"));
const log_1 = __importDefault(require("../util/log"));
const inject_1 = require("../actions/inject");
const manifest_1 = require("../sanity/manifest");
const init_1 = require("../actions/init");
const constants_1 = require("../constants");
const presets_1 = require("../presets/presets");
const description = `Inject configuration into a Sanity plugin`;
const help = `
Usage
  $ ${constants_1.cliName} inject [dir] [<args>]

Options
  --no-eslint             Disables ESLint config and dependencies from being added
  --no-prettier           Disables prettier config and dependencies from being added
  --no-typescript         Disables typescript config and dependencies from being added
  --no-license            Disables LICENSE + package.json license field from being added
  --no-editorconfig       Disables .editorconfig from being added
  --no-gitignore          Disables .gitignore from being added
  --no-scripts            Disables scripts from being added to package.json

  --license [spdx]        Use the license with the given SPDX identifier
  --force                 No promt when overwriting files

  --preset [preset-name]  [beta] - Adds config and files from a named preset. --preset can be supplied multiple times.
                          The following presets are available:
${(0, presets_1.presetHelpList)(30)}
  --preset-only           Skips the default inject steps. Use this to apply a preset to an otherwise complete plugin.

Examples
  # Inject configuration into the plugin in the current directory
  $ ${constants_1.cliName} inject

  # Inject configuration into the plugin in ~/my-plugin
  $ ${constants_1.cliName} inject ~/my-plugin

  # Don't inject eslint or prettier
  $ ${constants_1.cliName} inject --no-eslint --no-prettier

  # Inject plugin configuration and semver-workflow into the plugin in the current directory
  $ @sanity/plugin-kit inject --preset semver-workflow

  # Only inject semver-workflow and renovatebot config from presets
  $ ${constants_1.cliName} inject --preset-only --preset semver-workflow --preset renovatebot

`;
function run({ argv }) {
    return __awaiter(this, void 0, void 0, function* () {
        const cli = (0, meow_1.default)(help, { flags: init_1.initFlags, argv, description });
        const basePath = path_1.default.resolve(cli.input[0] || process.cwd());
        const { v3ConfigFile } = yield (0, manifest_1.findStudioV3Config)(basePath);
        if (v3ConfigFile) {
            throw new Error(`${v3ConfigFile} exists - are you trying to INJECT into a studio instead of a plugin?`);
        }
        log_1.default.info('Inject config into plugin in "%s"', basePath);
        yield (0, inject_1.inject)({ basePath, flags: cli.flags, validate: false });
        log_1.default.info('Done!');
    });
}
exports.default = run;
//# sourceMappingURL=inject.js.map