"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const meow_1 = __importDefault(require("meow"));
const constants_1 = require("../constants");
const verify_common_1 = require("../actions/verify/verify-common");
const verify_studio_1 = require("../actions/verify-studio");
const description = `Verify that a Sanity Studio is configured correctly for v3, and print upgrade steps if not.`;
const help = `
Usage
  $ ${constants_1.cliName} verify-studio [dir] [<args>]

Options
  --single      Enables fail-fast mode: Will only output the first validation that fails.
  --silent      Do not print info and warning messages
  --verbose     Log everything. This option conflicts with --silent
  --version     Output the version number
  --help        Output usage information

Each check will describe how they can be individually disabled.

Examples
  # Verify Sanity Studio in current directory
  $ ${constants_1.cliName} verify-studio

  # Verify Sanity Studio in my-sanity-studio directory in silent mode
  $ ${constants_1.cliName} verify-studio my-sanity-studio --silent
`;
function run({ argv }) {
    const cli = (0, meow_1.default)(help, { flags: verify_common_1.verifyFlags, argv, description });
    const basePath = path_1.default.resolve(cli.input[0] || process.cwd());
    return (0, verify_studio_1.verifyStudio)({ basePath, flags: cli.flags });
}
exports.default = run;
//# sourceMappingURL=verify-studio.js.map