"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateImports = void 0;
const log_1 = __importDefault(require("../util/log"));
const banned_packages_1 = require("../configs/banned-packages");
const constants_1 = require("../constants");
const eslint_1 = require("eslint");
const path_1 = __importDefault(require("path"));
const outdent_1 = __importDefault(require("outdent"));
const removedImportSuffix = `imports where removed in Sanity v3. Please refer to the migration guide: ${constants_1.urls.migrationGuideStudio}, or new API-reference docs: ${constants_1.urls.refDocs}`;
function validateImports({ basePath }) {
    return __awaiter(this, void 0, void 0, function* () {
        log_1.default.debug('Running ESLint with Sanity Studio import hints...');
        const eslint = new eslint_1.ESLint({
            cwd: basePath,
            overrideConfig: {
                ignorePatterns: ['node_modules'],
                rules: {
                    'no-restricted-imports': [
                        'error',
                        {
                            patterns: [
                                ...banned_packages_1.mergedPackages.map((packageName) => ({
                                    group: [`${packageName}*`],
                                    message: `Use sanity instead of ${packageName}.`,
                                })),
                                {
                                    group: ['config:*'],
                                    message: `config: imports are no longer supported. Please see the new plugin API for alternatives: ${constants_1.urls.migrationGuideStudio}`,
                                },
                                {
                                    group: ['part:*'],
                                    message: `part: ${removedImportSuffix}`,
                                },
                                {
                                    group: ['all:part:*'],
                                    message: `all:part: ${removedImportSuffix}`,
                                },
                                {
                                    group: ['sanity:*'],
                                    message: `sanity: ${removedImportSuffix}`,
                                },
                            ],
                        },
                    ],
                },
            },
        });
        try {
            const results = yield eslint.lintFiles([path_1.default.join(basePath, '**/*.{js,jsx,ts,tsx}')]);
            const onlyImportErrors = results
                .map((r) => {
                const limitErrors = r.messages.filter((m) => m.ruleId === 'no-restricted-imports');
                return Object.assign(Object.assign({}, r), { messages: limitErrors, errorCount: limitErrors.length });
            })
                .filter((r) => r.errorCount);
            if (onlyImportErrors.length) {
                const formatter = yield eslint.loadFormatter('stylish');
                const resultText = yield formatter.format(onlyImportErrors);
                const addtionalInfo = (0, outdent_1.default) `
        ESLint detected Studio V2 imports that are no longer available.
        It is recommended configure @sanity/eslint-config-no-v2-imports for ESLint.

        Run:
        npm install --save-dev @sanity/eslint-config-no-v2-imports

        In .eslintrc add:
        "extends": ["@sanity/no-v2-imports"]

        This way, V2-imports can be identified directly in the IDE, or using eslint CLI.
        For more, see ${constants_1.urls.linterPackage}

        If the plugin package does not use eslint, disable this check.
    `;
                return [resultText + addtionalInfo];
            }
        }
        catch (e) {
            log_1.default.error('Failed to run eslint check', e);
            return [
                (0, outdent_1.default) `
        Failed to run ESLint. Is ESLint configured?
        It is recommended to install eslint-config-sanity and add 'sanity/upgrade-v2' to your eslint-extends config.

        Run:
        npm install --save-dev eslint-config-sanity

        In .eslintrc add:
        extends: ['sanity/upgrade-v2']

        This way, V2-imports can be identified directly in the IDE, or using eslint CLI.
        If the package does not use eslint, disable this check.
    `,
            ];
        }
        return [];
    });
}
exports.validateImports = validateImports;
//# sourceMappingURL=import-linter.js.map