"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.injectPresets = exports.presetHelpList = void 0;
const semver_workflow_1 = require("./semver-workflow");
const renovatebot_1 = require("./renovatebot");
const presets = [semver_workflow_1.semverWorkflowPreset, renovatebot_1.renovatePreset];
const presetNames = presets.map((p) => p === null || p === void 0 ? void 0 : p.name);
function presetHelpList(padStart) {
    return presets
        .map((p) => `${''.padStart(padStart)}${p.name.padEnd(20)}${p.description}`)
        .join('\n');
}
exports.presetHelpList = presetHelpList;
function injectPresets(options) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        if (options.flags.presetOnly && !((_a = options.flags.preset) === null || _a === void 0 ? void 0 : _a.length)) {
            throw new Error('--preset-only, but no --preset [preset-name] was provided.');
        }
        const applyPresets = presetsFromInput(options.flags.preset);
        for (const preset of applyPresets) {
            yield preset.apply(options);
        }
    });
}
exports.injectPresets = injectPresets;
function presetsFromInput(inputPresets) {
    if (!inputPresets) {
        return [];
    }
    const unknownPresets = inputPresets.filter((p) => !presetNames.includes(p));
    if (unknownPresets.length) {
        throw new Error(`Unknown --preset(s): [${unknownPresets.join(', ')}]. Must be one of: [${presetNames.join(', ')}]`);
    }
    return inputPresets
        .filter(onlyUnique)
        .map((presetName) => presets.find((p) => p.name === presetName))
        .filter((p) => !!p);
}
function onlyUnique(value, index, arr) {
    return arr.indexOf(value) === index;
}
//# sourceMappingURL=presets.js.map