"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.promptForRepoOrigin = exports.promptForPackageName = exports.prompt = void 0;
const url_1 = require("url");
const path_1 = __importDefault(require("path"));
const inquirer_1 = __importDefault(require("inquirer"));
// @ts-expect-error missing types
const validate_npm_package_name_1 = __importDefault(require("validate-npm-package-name"));
// @ts-expect-error missing types
const github_url_to_object_1 = __importDefault(require("github-url-to-object"));
function prompt(message, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const type = options.choices ? 'list' : options.type;
        const result = yield inquirer_1.default.prompt([Object.assign(Object.assign({}, options), { type, message, name: 'single' })]);
        return result && result.single;
    });
}
exports.prompt = prompt;
prompt.separator = () => new inquirer_1.default.Separator();
function promptForPackageName({ basePath }, defaultVal) {
    return prompt('Plugin name (sanity-plugin-...)', {
        default: defaultVal || path_1.default.basename(basePath),
        filter: (name) => {
            const prefixless = name.trim().replace(/^sanity-plugin-/, '');
            return name[0] === '@' ? name : `sanity-plugin-${prefixless}`;
        },
        validate: (name) => {
            const valid = (0, validate_npm_package_name_1.default)(name);
            if (valid.errors) {
                return valid.errors[0];
            }
            if (name[0] !== '@' && name.endsWith('plugin')) {
                return `Name shouldn't include "plugin" multiple times (${name})`;
            }
            return true;
        },
    });
}
exports.promptForPackageName = promptForPackageName;
function promptForRepoOrigin(options, defaultVal) {
    return prompt('Git repository URL', {
        default: defaultVal,
        filter: (raw) => {
            const url = (raw || '').trim();
            const gh = (0, github_url_to_object_1.default)(url);
            return gh ? `git+ssh://git@github.com/${gh.user}/${gh.repo}.git` : url;
        },
        validate: (url) => {
            if (!url) {
                return true;
            }
            try {
                const parsed = new url_1.URL(url);
                return parsed ? true : 'Invalid URL';
            }
            catch (err) {
                return 'Invalid URL';
            }
        },
    });
}
exports.promptForRepoOrigin = promptForRepoOrigin;
//# sourceMappingURL=prompt.js.map