"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const execa_1 = __importDefault(require("execa"));
const tap_1 = __importDefault(require("tap"));
const fixture_utils_1 = require("./fixture-utils");
const outdent_1 = __importDefault(require("outdent"));
tap_1.default.test('plugin-kit init -> verify-package -> tsc > pkg-utils build', (t) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, fixture_utils_1.testFixture)({
        fixturePath: 'init/empty',
        relativeOutPath: 'buildable',
        command: ({ outputDir }) => __awaiter(void 0, void 0, void 0, function* () {
            // using console.error: we want these logged continuously to not surprise devs on the runtime
            console.error('Integration testing init -> verify-package -> tsc -> build.\nThis may take a while...');
            let start = new Date().getTime();
            function seconds() {
                return `${(new Date().getTime() - start) / 1000}s`;
            }
            const init = yield (0, fixture_utils_1.runCliCommand)('init', [outputDir, ...fixture_utils_1.initTestArgs]);
            console.error(`"plugin-kit init" done in ${seconds()}.\nRunning "plugin-kit verify-package"...`);
            start = new Date().getTime();
            const verify = yield (0, fixture_utils_1.runCliCommand)('verify-package', [outputDir]);
            console.error(`"plugin-kit verify-package" done in ${seconds()}.\nRunning "tcs --noEmit"...`);
            start = new Date().getTime();
            const tsc = yield (0, execa_1.default)('tsc', ['--noEmit'], { cwd: outputDir });
            console.error(`"tsc --noEmit" done in ${seconds()}.\nRunning "pkg-utils build"...`);
            start = new Date().getTime();
            const build = yield (0, execa_1.default)('pkg-utils', ['build'], { cwd: outputDir });
            console.error(`"pkg-utils build" done in ${seconds()}.`);
            return {
                stdout: (0, outdent_1.default) `
          ${init.stdout}
          ${verify.stdout}
          ${tsc.stdout}
          ${build.stdout}
        `,
                stderr: (0, outdent_1.default) `
          ${init.stderr}
          ${verify.stderr}
          ${tsc.stderr}
          ${build.stderr}
        `,
            };
        }),
        assert: ({ result: { stdout, stderr }, outputDir }) => __awaiter(void 0, void 0, void 0, function* () {
            const trimmedErrors = stderr
                .split('\n')
                .filter((line) => !line.trim()) // remove empty lines
                .join('\n')
                .trim();
            t.equal(trimmedErrors, '', 'should have empty stderr');
            t.strictSame(yield (0, fixture_utils_1.contents)(path_1.default.join(outputDir, 'lib')), ['index.esm.js', 'index.esm.js.map', 'index.js', 'index.js.map', 'src/index.d.ts'].map(fixture_utils_1.normalize), 'should output expected files to lib');
        }),
    });
}));
//# sourceMappingURL=init-verify-build.test.js.map