"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tap_1 = __importDefault(require("tap"));
const fixture_utils_1 = require("./fixture-utils");
const path_1 = __importDefault(require("path"));
const files_1 = require("../src/util/files");
const constants_1 = require("../src/constants");
const defaultDevDependencies = [
    '@sanity/pkg-utils',
    '@sanity/plugin-kit',
    '@typescript-eslint/eslint-plugin',
    '@typescript-eslint/parser',
    'eslint',
    'eslint-config-prettier',
    'eslint-config-sanity',
    'eslint-plugin-prettier',
    'eslint-plugin-react',
    'eslint-plugin-react-hooks',
    'prettier',
    'react',
    'rimraf',
    'sanity',
    'typescript',
];
tap_1.default.test('plugin-kit init --force in empty directory', (t) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, fixture_utils_1.testFixture)({
        fixturePath: 'init/empty',
        relativeOutPath: 'defaults',
        command: ({ outputDir }) => (0, fixture_utils_1.runCliCommand)('init', [outputDir, ...fixture_utils_1.initTestArgs]),
        assert: ({ result: { stdout, stderr }, outputDir }) => __awaiter(void 0, void 0, void 0, function* () {
            var _a, _b, _c;
            t.equal(stderr, '', 'should have empty stderr');
            t.match(stdout, `Initializing new plugin in "${outputDir}"`);
            const fileContains = (0, fixture_utils_1.fileContainsValidator)(t, outputDir);
            yield fileContains('LICENSE', 'MIT');
            yield fileContains('README.md', `# ${fixture_utils_1.pluginTestName}`);
            yield fileContains('.gitignore', 'lib');
            yield fileContains('.eslintrc', 'sanity', 'sanity/typescript', 'sanity/react', 'plugin:react-hooks/recommended', 'plugin:prettier/recommended');
            yield fileContains('.eslintignore', '.eslintrc.js', 'commitlint.config.js', 'lib', 'lint-staged.config.js', '*.js');
            yield fileContains('.npmignore', '/test');
            yield fileContains('.prettierrc.js', 'semi: false');
            yield fileContains('sanity.json', '"path": "./v2-incompatible.js"');
            yield fileContains('v2-incompatible.js', 'showIncompatiblePluginDialog');
            yield fileContains('tsconfig.json', '"target": "esnext"');
            yield fileContains('src/index.ts', `name: '${fixture_utils_1.pluginTestName}'`);
            const pkg = JSON.parse(yield (0, fixture_utils_1.readFile)(path_1.default.join(outputDir, 'package.json')));
            t.has(pkg, {
                name: fixture_utils_1.pluginTestName,
                version: '1.0.0',
                description: '',
                // author: 'Omitted from validation',
                license: 'MIT',
                source: './src/index.ts',
                exports: {
                    '.': {
                        types: './lib/src/index.d.ts',
                        source: './src/index.ts',
                        import: './lib/index.esm.js',
                        require: './lib/index.js',
                        default: './lib/index.js',
                    },
                },
                main: './lib/index.js',
                module: './lib/index.esm.js',
                types: './lib/src/index.d.ts',
                files: ['src', 'lib', 'v2-incompatible.js', 'sanity.json'],
                scripts: {
                    clean: 'rimraf lib',
                    lint: 'eslint .',
                    prebuild: 'npm run clean && plugin-kit verify-package --silent && pkg-utils',
                    build: 'pkg-utils build',
                    watch: 'pkg-utils watch',
                    'link-watch': 'plugin-kit link-watch',
                    prepublishOnly: 'npm run build',
                },
                repository: {
                    type: 'git',
                    url: 'https://github.com/sanity-io/sanity',
                },
                engines: {
                    node: '>=14.0.0',
                },
                bugs: {
                    url: 'https://github.com/sanity-io/sanity/issues',
                },
                homepage: 'https://github.com/sanity-io/sanity#readme',
            }, 'package.json has expected content');
            t.strictSame(Object.keys((_a = pkg.dependencies) !== null && _a !== void 0 ? _a : {}), [constants_1.incompatiblePluginPackage], 'should have empty dependencies');
            t.strictSame(Object.keys((_b = pkg.peerDependencies) !== null && _b !== void 0 ? _b : {}), ['react', 'sanity'], 'should have expected peerDependencies');
            t.strictSame(Object.keys((_c = pkg.devDependencies) !== null && _c !== void 0 ? _c : {}), defaultDevDependencies, 'should have expected devDependencies');
        }),
    });
}));
tap_1.default.test('plugin-kit init --force with all the opt-outs in empty directory', (t) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, fixture_utils_1.testFixture)({
        fixturePath: 'init/empty',
        relativeOutPath: 'opt-out',
        command: ({ outputDir }) => (0, fixture_utils_1.runCliCommand)('init', [
            outputDir,
            ...fixture_utils_1.initTestArgs.filter((a) => a !== '--license' && a !== 'mit'),
            '--no-install',
            '--no-eslint',
            '--no-prettier',
            '--no-typescript',
            '--no-license',
            '--no-editorconfig',
            '--no-gitignore',
            '--no-scripts',
        ]),
        assert: ({ result: { stdout, stderr }, outputDir }) => __awaiter(void 0, void 0, void 0, function* () {
            var _d, _e, _f;
            t.equal(stderr, '', 'should have empty stderr');
            t.match(stdout, `Initializing new plugin in "${outputDir}"`);
            const fileContains = (0, fixture_utils_1.fileContainsValidator)(t, outputDir);
            const expectNotExist = (file) => __awaiter(void 0, void 0, void 0, function* () { return t.notOk(yield (0, files_1.fileExists)(path_1.default.join(outputDir, (0, fixture_utils_1.normalize)(file))), `${file} should not exist`); });
            yield expectNotExist('LICENSE');
            yield expectNotExist('.eslintrc');
            yield expectNotExist('.gitignore');
            yield expectNotExist('.prettierrc.js');
            yield expectNotExist('tsconfig.json');
            yield fileContains('src/index.js', `name: '${fixture_utils_1.pluginTestName}'`);
            const pkg = JSON.parse(yield (0, fixture_utils_1.readFile)(path_1.default.join(outputDir, 'package.json')));
            t.same(pkg.scripts, {}, 'scripts should be an empty object');
            t.strictSame(Object.keys((_d = pkg.dependencies) !== null && _d !== void 0 ? _d : {}), [constants_1.incompatiblePluginPackage], 'should have empty dependencies');
            t.strictSame(Object.keys((_e = pkg.peerDependencies) !== null && _e !== void 0 ? _e : {}), ['react', 'sanity'], 'should have expected peerDependencies');
            t.strictSame(Object.keys((_f = pkg.devDependencies) !== null && _f !== void 0 ? _f : {}), ['@sanity/pkg-utils', '@sanity/plugin-kit', 'react', 'rimraf', 'sanity'], 'should have expected devDependencies');
        }),
    });
}));
tap_1.default.test('plugin-kit init --force --preset semver-workflow in empty directory', (t) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, fixture_utils_1.testFixture)({
        fixturePath: 'init/empty',
        relativeOutPath: 'defaults-semver-workflow',
        command: ({ outputDir }) => (0, fixture_utils_1.runCliCommand)('init', [outputDir, ...fixture_utils_1.initTestArgs, '--preset', 'semver-workflow']),
        assert: ({ result: { stdout, stderr }, outputDir }) => __awaiter(void 0, void 0, void 0, function* () {
            var _g, _h;
            t.equal(stderr, '', 'should have empty stderr');
            const fileContains = (0, fixture_utils_1.fileContainsValidator)(t, outputDir);
            yield fileContains(path_1.default.join('.github', 'workflows', 'main.yml'), 'CI & Release');
            yield fileContains(path_1.default.join('.husky', 'commit-msg'), 'npx --no -- commitlint');
            yield fileContains(path_1.default.join('.husky', 'pre-commit'), 'npx lint-staged');
            yield fileContains(path_1.default.join('.releaserc.json'), '@sanity/semantic-release-preset');
            yield fileContains(path_1.default.join('commitlint.config.js'), '@commitlint/config-conventional');
            const pkg = JSON.parse(yield (0, fixture_utils_1.readFile)(path_1.default.join(outputDir, 'package.json')));
            t.strictSame(Object.keys((_g = pkg.devDependencies) !== null && _g !== void 0 ? _g : {}), [
                ...defaultDevDependencies,
                '@commitlint/cli',
                '@commitlint/config-conventional',
                '@sanity/semantic-release-preset',
                'husky',
                'lint-staged',
            ].sort(), 'should have expected devDependencies');
            t.strictSame((_h = pkg.scripts) === null || _h === void 0 ? void 0 : _h.prepare, 'husky install');
        }),
    });
}));
//# sourceMappingURL=init.test.js.map