"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tap_1 = __importDefault(require("tap"));
const fixture_utils_1 = require("./fixture-utils");
const path_1 = __importDefault(require("path"));
const fs_extra_1 = require("fs-extra");
tap_1.default.test('plugin-kit inject --preset semver-workflow into existing plugin directory', (t) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, fixture_utils_1.testFixture)({
        fixturePath: 'inject/valid',
        relativeOutPath: '../semver-workflow',
        command: ({ fixtureDir, outputDir }) => __awaiter(void 0, void 0, void 0, function* () {
            (0, fs_extra_1.copySync)(fixtureDir, outputDir);
            return (0, fixture_utils_1.runCliCommand)('inject', [outputDir, '--preset-only', '--preset', 'semver-workflow']);
        }),
        assert: ({ result: { stdout, stderr }, outputDir }) => __awaiter(void 0, void 0, void 0, function* () {
            t.equal(stderr, '', 'should have empty stderr');
            t.match(stdout, `Only apply presets, skipping default inject.`);
            t.match(stdout, `Inject config into plugin in "${outputDir}"`);
            const fileContains = (0, fixture_utils_1.fileContainsValidator)(t, outputDir);
            // only check for a single file from the preset:
            // rest is covered by the init tests; it uses the same codepath
            yield fileContains(path_1.default.join('.github', 'workflows', 'main.yml'), 'CI & Release');
        }),
    });
}));
tap_1.default.test('plugin-kit inject --preset renovatebot into existing plugin directory', (t) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, fixture_utils_1.testFixture)({
        fixturePath: 'inject/valid',
        relativeOutPath: '../renovatebot',
        command: ({ fixtureDir, outputDir }) => __awaiter(void 0, void 0, void 0, function* () {
            (0, fs_extra_1.copySync)(fixtureDir, outputDir);
            return (0, fixture_utils_1.runCliCommand)('inject', [outputDir, '--preset-only', '--preset', 'renovatebot']);
        }),
        assert: ({ result: { stdout, stderr }, outputDir }) => __awaiter(void 0, void 0, void 0, function* () {
            t.equal(stderr, '', 'should have empty stderr');
            const fileContains = (0, fixture_utils_1.fileContainsValidator)(t, outputDir);
            yield fileContains(path_1.default.join('renovate.json'), '"github>sanity-io/renovate-presets//ecosystem/auto"');
        }),
    });
}));
tap_1.default.test('plugin-kit inject --preset-only requires --preset', (t) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, fixture_utils_1.testFixture)({
        fixturePath: 'inject/valid',
        command: ({ fixtureDir }) => __awaiter(void 0, void 0, void 0, function* () {
            return (0, fixture_utils_1.runCliCommand)('inject', [fixtureDir, '--preset-only']);
        }),
        assert: ({ result: { stdout, stderr }, outputDir }) => __awaiter(void 0, void 0, void 0, function* () {
            t.match(stderr, '--preset-only, but no --preset [preset-name] was provided.');
        }),
    });
}));
tap_1.default.test('plugin-kit inject --preset-only --preset does-not-exist', (t) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, fixture_utils_1.testFixture)({
        fixturePath: 'inject/valid',
        command: ({ fixtureDir }) => __awaiter(void 0, void 0, void 0, function* () {
            return (0, fixture_utils_1.runCliCommand)('inject', [fixtureDir, '--preset-only', '--preset', 'does-not-exist']);
        }),
        assert: ({ result: { stdout, stderr }, outputDir }) => __awaiter(void 0, void 0, void 0, function* () {
            t.match(stderr, 'Unknown --preset(s): [does-not-exist]. Must be one of: [');
        }),
    });
}));
//# sourceMappingURL=inject.test.js.map