"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tap_1 = __importDefault(require("tap"));
const fixture_utils_1 = require("./fixture-utils");
const verify_common_1 = require("../src/actions/verify/verify-common");
tap_1.default.test('plugin-kit verify-package in package with all checks failing', (t) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, fixture_utils_1.testFixture)({
        fixturePath: 'verify-package/every-failure-possible',
        command: ({ fixtureDir }) => (0, fixture_utils_1.runCliCommand)('verify-package', [fixtureDir]),
        assert: ({ result: { stderr } }) => __awaiter(void 0, void 0, void 0, function* () {
            const redactFilePaths = cleanupOutput(stderr, /[\S]+verify-package\/every-failure-possible\//g);
            // to regenerate the snapshot, in root dir run:
            // tap test/verify-package.test.ts --snapshot
            t.matchSnapshot(redactFilePaths, 'stderr should match snapshot');
            // checks that output contains the "skip this validation" snippet for every possible relevant key
            // will fail when new checks are added that we may or may not want to account for
            Object.keys(verify_common_1.verifyPackageConfigDefaults)
                .filter((key) => !['tsc', 'studioConfig'].includes(key))
                .forEach((checkKey) => {
                const findString = `"${checkKey}": false`;
                t.ok(stderr.includes(findString), `should include ${findString} in stderr`);
            });
        }),
    });
}));
tap_1.default.test('plugin-kit verify-package in ok package', (t) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, fixture_utils_1.testFixture)({
        fixturePath: 'verify-package/valid',
        command: ({ fixtureDir }) => (0, fixture_utils_1.runCliCommand)('verify-package', [fixtureDir]),
        assert: ({ result: { stdout, stderr } }) => __awaiter(void 0, void 0, void 0, function* () {
            t.equal(stderr, '', 'stderr should be empty');
            // to regenerate the snapshot, in root dir run:
            // tap test/verify-package.test.ts --snapshot
            const redactFilePaths = cleanupOutput(stdout, /[\S]+verify-package\/valid\//g);
            t.matchSnapshot(redactFilePaths, 'stdout should match snapshot');
        }),
    });
}));
tap_1.default.test('plugin-kit verify-package in package with invalid eslint config', (t) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, fixture_utils_1.testFixture)({
        fixturePath: 'verify-package/invalid-eslint',
        command: ({ fixtureDir }) => (0, fixture_utils_1.runCliCommand)('verify-package', [fixtureDir]),
        assert: ({ result: { stdout, stderr }, outputDir }) => __awaiter(void 0, void 0, void 0, function* () {
            // to regenerate the snapshot, in root dir run:
            // tap test/verify-package.test.ts --snapshot
            const redactFilePaths = cleanupOutput(stderr, /[\S]+verify-package\/invalid-eslint\//g);
            t.matchSnapshot(redactFilePaths, 'stderr should match snapshot');
        }),
    });
}));
tap_1.default.test('plugin-kit verify-studio in fresh v2 studio', (t) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, fixture_utils_1.testFixture)({
        fixturePath: 'verify-package/fresh-v2-movie-studio',
        command: ({ fixtureDir }) => (0, fixture_utils_1.runCliCommand)('verify-studio', [fixtureDir]),
        assert: ({ result: { stdout, stderr } }) => __awaiter(void 0, void 0, void 0, function* () {
            // to regenerate the snapshot, in root dir run:
            // tap test/verify-package.test.ts --snapshot
            const redactFilePaths = cleanupOutput(stderr, /[\S]+verify-package\/fresh-v2-movie-studio\//g);
            t.matchSnapshot(redactFilePaths, 'stderr should match snapshot');
        }),
    });
}));
function cleanupOutput(val, packagePath) {
    return val
        .replace(packagePath, 'root/')
        .replace(/\((.+)\/node_modules\//g, 'root/node_modules/')
        .replace(/\[\d+m/g, '');
}
//# sourceMappingURL=verify-package.test.js.map