"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tap_1 = __importDefault(require("tap"));
const package_json_1 = __importDefault(require("../package.json"));
const fixture_utils_1 = require("./fixture-utils");
tap_1.default.test('shows full version if no flag is given', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const { stdout, stderr, exitCode } = yield (0, fixture_utils_1.runCliCommand)('version', []);
    t.equal(exitCode, 0, 'should have exit code 0');
    t.equal(stderr, '', 'stderr should be empty');
    t.equal(stdout, `${package_json_1.default.name} version ${package_json_1.default.version}`);
}));
tap_1.default.test('shows major version if --major is given', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const { stdout, stderr, exitCode } = yield (0, fixture_utils_1.runCliCommand)('version', ['--major']);
    t.equal(exitCode, 0, 'should have exit code 0');
    t.equal(stderr, '', 'stderr should be empty');
    t.equal(stdout, package_json_1.default.version.split('.')[0]);
}));
tap_1.default.test('shows minor version if --minor is given', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const { stdout, stderr, exitCode } = yield (0, fixture_utils_1.runCliCommand)('version', ['--minor']);
    t.equal(exitCode, 0, 'should have exit code 0');
    t.equal(stderr, '', 'stderr should be empty');
    t.equal(stdout, package_json_1.default.version.split('.')[1]);
}));
tap_1.default.test('shows patch version if --patch is given', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const { stdout, stderr, exitCode } = yield (0, fixture_utils_1.runCliCommand)('version', ['--patch']);
    t.equal(exitCode, 0, 'should have exit code 0');
    t.equal(stderr, '', 'stderr should be empty');
    t.equal(stdout, package_json_1.default.version.split('.')[2]);
}));
tap_1.default.test('throws if two version flags are given', (t) => __awaiter(void 0, void 0, void 0, function* () {
    const { stdout, stderr, exitCode } = yield (0, fixture_utils_1.runCliCommand)('version', ['--major', '--minor']);
    t.equal(exitCode, 1, 'exit code should be 1');
    t.equal(stdout, '', 'stdout should be empty');
    t.match(stderr, 'only one can be used at a time');
}));
//# sourceMappingURL=version.test.js.map